@@ -1,10 +1,7 @@
 package Net::Identica;
+$Net::Identica::VERSION = '4.01002';
 use Moose;
 
-# use *all* digits for fBSD ports
-our $VERSION = '3.10003';
-$VERSION     = eval $VERSION; # numify for warning-free dev releases
-
 extends 'Net::Twitter::Core';
 with map "Net::Twitter::Role::$_", qw/Legacy/;
 
@@ -23,6 +20,10 @@ __END__
 
 Net::Identica - A perl interface to the Identi.ca Twitter Compatible API
 
+=head1 VERSION
+
+version 4.01002
+
 =head1 SYNOPSIS
 
   use Net::Identica;
@@ -31,6 +32,33 @@ Net::Identica - A perl interface to the Identi.ca Twitter Compatible API
 
   $nt->update('Hello, Identica friends!');
 
+=head1 DEPRECATED
+
+This module is a backwards compatibility wrapper for applications that used
+L<Net::Identica> packaged with C<Net::Twitter> versions 2.12 and earlier.
+Instead, use L<Net::Twitter> with the C<identica> option to gain all of the new
+features and functionality (OAuth, Search, exceptions on error, etc.).
+
+  use Net::Twitter;
+
+  # A simple, backwards compatible replacement for Net::Identica
+  my $identica = Net::Twitter->new(
+      legacy   => 1,
+      identica => 1,
+      username => $username,
+      password => $password,
+  );
+
+  # A more complex object with OAuth and some optional traits
+  my $identica = Net::Twitter->new(
+      traits => [qw/API::REST API::Search InflateObjects/],
+      identica            => 1,
+      consumer_key        => $consumer_key,
+      consumer_secret     => $consumer_secret,
+      access_token        => $token,
+      access_token_secret => $token_secret,
+  );
+
 =head1 DESCRIPTION
 
 The micro-blogging service L<http://identi.ca> provides a Twitter compatible API.
